<?php
class wpwhoosh_pin {

    private static $initialized = false;
    private static $slug = WPWHOOSH_PIN;
    private static $screen_id;
    private static $label;
    private static $pin;
	private static $tips = array(
			'pin' => array('heading' => 'PIN', 'tip' => 'Supply a PIN of between 4 and 8 digits. You will need to remember your PIN as you will need it for every installation.'),
			'authorization' => array ('heading' => 'Authorization', 'tip' => 'Copy the authorization code from the email we sent you and paste it into the box. It should be 32 characters in length.'),
			'key' => array('heading' => 'API Key', 'tip' => 'Copy your API key from the email and paste it into the box')
			);
	private static $tooltips;

	static function init() {
	    if (self::$initialized) return true;
		self::$initialized = true;
		self::$label = WPWHOOSH_FRIENDLY_NAME.' '.__('API Key',WPWHOOSH_PLUGIN_NAME);
		self::$pin = WPWHOOSH_FRIENDLY_NAME.' '.__('PIN',WPWHOOSH_PLUGIN_NAME);
		self::$tooltips = new wpwhoosh_tooltip(self::$tips);
		add_action('admin_menu', array(WPWHOOSH_PIN, 'admin_menu'));
	}

	static function admin_menu() {
		self::$screen_id = add_submenu_page(WPWHOOSH_PLUGIN_NAME, self::$pin, __('PIN',WPWHOOSH_PLUGIN_NAME), 'read', 
			self::get_slug(), array(WPWHOOSH_PIN,'controller'));
		add_filter('screen_layout_columns', array(WPWHOOSH_PIN, 'screen_layout_columns'), 10, 2);
		add_action('load-'.self::get_screen_id(), array(WPWHOOSH_PIN, 'load_page'));
		add_action('admin_footer-'.self::get_screen_id(), array(WPWHOOSH_PIN, 'toggle_postboxes'));
	}

    static function get_slug() {
		return self::$slug;
	}

    static function get_screen_id(){
		return self::$screen_id;
	}

 	static function get_url($action='',$noheader=false,$with_nonce=false) {
 		return WPWhooshUtils::admin_url(self::get_slug(), $action, '', $noheader, $with_nonce);       
	}

	static function screen_layout_columns($columns, $screen) {
		if (!defined( 'WP_NETWORK_ADMIN' ) && !defined( 'WP_USER_ADMIN' )) {
			if ($screen == self::get_screen_id()) {
				$columns[self::get_screen_id()] = 2;
			}
		}
		return $columns;
	}

	public static function enqueue_styles() {
		wp_enqueue_style('tooltip', WPWHOOSH_PLUGIN_URL.'tooltip.css', array(),WPWHOOSH_VERSION);	
		wp_enqueue_style('pin', WPWHOOSH_PLUGIN_URL.'pin.css', array(),WPWHOOSH_VERSION);	
 	}

	public static function enqueue_scripts() {
		wp_enqueue_script('pin', WPWHOOSH_PLUGIN_URL.'pin.js', array('jquery'), WPWHOOSH_VERSION, true);
		wp_enqueue_script('crypto',WPWHOOSH_PLUGIN_URL.'md5.js',array(),'3.0.2',true);			
		wp_enqueue_script('common');
		wp_enqueue_script('wp-lists');
		wp_enqueue_script('postbox');	
	}


	static function load_page() {
		add_action ('admin_enqueue_scripts',array(WPWHOOSH_PIN, 'enqueue_styles'));
		add_action ('admin_enqueue_scripts',array(WPWHOOSH_PIN, 'enqueue_scripts'));		
		add_meta_box('pin-panel', self::$pin, array(WPWHOOSH_PIN, 'pin_panel'), self::get_screen_id(), 'normal', 'core');
		$current_screen = get_current_screen();
		if (method_exists($current_screen,'add_help_tab')) {		
			$current_screen->add_help_tab( array( 'id' => 'wpwhoosh_pin_protect', 'title' => self::$pin, 'content' => self::pin_protect_help()));		
			$current_screen->add_help_tab( array( 'id' => 'wpwhoosh_pin_reason', 'title' => 'Why Have A PIN?', 'content' => self::pin_reasons_help()));		
			$current_screen->add_help_tab( array( 'id' => 'wpwhoosh_pin_change', 'title' => 'How To Set Your PIN', 'content' => self::pin_change_help()));		
		}	
	}

    static function toggle_postboxes() {
    	$hook = self::get_screen_id();
    	print <<< TOGGLE_POSTBOXES
<script type="text/javascript">
//<![CDATA[
		jQuery(document).ready( function($) {
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			postboxes.add_postbox_toggles('{$hook}');
		});
//]]>
</script>
TOGGLE_POSTBOXES;
    }

	private static function change_pin() {
    	$redir = WPWhooshUtils::next_url('change_pin'); //check nonce 
		$args = array('action' => 'pin_change', 'timeout' => 30, 
			'body' => array('pin' => $_POST['pin'], 'auth' => $_POST['authorization']));
		$status = WPWhooshUpdater::update(false, $args);
		if ($status['success']) {
			$message = __('Your PIN has been changed',WPWHOOSH_PLUGIN_NAME);
		} else {
			$message = __('PIN changes are not available at this time:',WPWHOOSH_PLUGIN_NAME). $status['error'];
		}
		$redir = add_query_arg( array('message' => urlencode($message)), $redir );  
    	wp_redirect( $redir ); 
    	exit;
	}

	private static function reset_pin() {
    	$redir = WPWhooshUtils::next_url('reset_pin'); 
		$args = array('action' => 'pin_reset', 'timeout' => 30);
		$status = WPWhooshUpdater::update(false, $args);
		if ($status['success']) {
				$message = WPWhooshUpdater::get_notice(). '<br/>'. __('Copy the authorization code from the email and paste it below next to your new PIN',WPWHOOSH_PLUGIN_NAME);
		} else {
			$message = __('PIN authorization requests are not being accepted at this time:',WPWHOOSH_PLUGIN_NAME). WPWhooshUtils::get_errors($status);
		}
		$redir = add_query_arg( array('message' => urlencode($message)), $redir );  
    	wp_redirect( $redir ); 
    	exit;
	}

	static function pin_panel($post, $metabox) {		
		$home = WPWHOOSH_HOME_URL;	
		$pin = self::$pin;	
		$is_valid = false;
		$notice ='';
 		$reset_url = self::get_url('reset_pin',true,true);       
 		$change_url = self::get_url('change_pin',true,true);    
 		$pin_action = WPWhooshUpdater::get_pin_enabled() ? 'Change' : 'Create';  
		$tip1 = self::$tooltips->tip('pin');
		$tip2 = self::$tooltips->tip('authorization');
		print <<< PIN_PANEL
<h4>How To {$pin_action} Your Pin</h4>
<p>To get a PIN for the first time or change your existing PIN: <ol>
<li>Think up your new PIN and make sure you can remember it as we won't be able to help you retrieve it. It can be between 4 and 8 characters long. Type it into the box below.</li>
<li>Request an authorization code by clicking this link: <a href="{$reset_url}">Request Authorization Code</a>.</li>
<li>Check your email and copy the authorization code we've sent and paste it below next to your new PIN.</li>
<li>Click the button</li>
</ol></p>
<form id="pin_entry" method="post" onsubmit="return wpwhoosh_validate_pin(this);" action="{$change_url}"> 
{$tip1}<input type="password" name="pin" id="pin"  maxlength="8" /><br/>
{$tip2}<input type="text" name="authorization" id="authorization" value="Copy the authorization code from your email" /><br/>
<p><input type="hidden" name="action" value="change_pin"/><input type="submit" class="button-primary" value="{$pin_action} PIN" /></p>
</form>
PIN_PANEL;
	}

	static function pin_protect_help() {		
		$url = WPWHOOSH_HOME_URL . '/tutorials/how-to-change-your-whoosh-pin/';	
		$friendly_name = WPWHOOSH_FRIENDLY_NAME;	
		$label = self::$label;
		$pin = self::$pin;
		$panel = <<< PIN_HELP_PANEL
<h4>Protect Your {$label} With A {$pin}</h4>
<p>With {$friendly_name} a PIN (personal identification number) is optional but recommended.  The PIN can be between 4 and 8 digits long. Every time you spend credits then you 
will be prompted to enter your PIN. The PIN is encrypted in the browser and used to encrypt the access information 
that is required to install the new site.</p> 
<p>To maintain security, your {$pin} is never displayed or sent as free text. In fact it is not recoverable at all. In case of loss you need to set a new PIN.</p>
PIN_HELP_PANEL;
		return $panel;
	}

	static function pin_reasons_help() {		
		$url = WPWHOOSH_HOME_URL . '/tutorials/how-to-change-your-whoosh-pin/';	
		$friendly_name = WPWHOOSH_FRIENDLY_NAME;	
		$label = self::$label;
		$pin = self::$pin;
		$panel = <<< PIN_HELP_PANEL
<h4>Reasons To Use A PIN</h4>
<p>If you have set a PIN you will be asked to enter you PIN every time you want to spend some credits. Setting a PIN ensures that 
<ol>
<li>even if someone finds out your API key, they cannot spend your credits without knowing your PIN; and</li>
<li>even if a hacker or some other unauthorized person obtains admin access to your WordPress site, your host details cannot be accessed without knowing your PIN</li>
</ol></p>
<p>For security reasons, if you lose or change your PIN, then you will need to reenter your host details.</p>
PIN_HELP_PANEL;
		return $panel;
	}

	static function pin_change_help() {		
		$url = WPWHOOSH_HOME_URL . '/tutorials/how-to-change-your-whoosh-pin/';	
		$friendly_name = WPWHOOSH_FRIENDLY_NAME;	
		$label = self::$label;
		$pin = self::$pin;
		$panel = <<< PIN_HELP_PANEL
<h4>How To Create Your PIN or Change Your PIN</h4>
<p>If you lose or forget your PIN, or simply want to change it, you can do so by following a two-step procedure. Firstly you request
a change of PIN below and the system will email your primary email address an authorization code which lasts for 15 minutes. Secondly, you then 
choose a new PIN and enter the authorization code. If the authorization code is valid the new PIN will become active.</p>
<p>If you set an empty new PIN, then the PIN challenge will be disabled.</p>
<p>For more detailed instructions check out the tutorial at <a target="_blank" href="{$url}">How To Change Your {$pin}</a></p>
PIN_HELP_PANEL;
		return $panel;
	}




    static private function fetch_message($action) {
		$actions = empty($action) ? array() : (is_array($action) ? $action : array($action));
		$show_message = '' ;
		if (isset($_REQUEST['message']) && ! empty($_REQUEST['message'])) { 
			if ((count($actions) == 0)
			|| (array_key_exists('lastaction',$_REQUEST)  && in_array($_REQUEST['lastaction'],$actions))) {
				$message = urldecode($_REQUEST['message']);
				$style = strpos($message,'success') !== FALSE ? ' success' : (strpos($message,'fail') !== FALSE ? ' failure' : '');
				$show_message = sprintf ('<div id="message" class="%2$s"><div class="updated">%1$s</div></div>',$message,$style); 
				$_SERVER['REQUEST_URI'] = remove_query_arg(array('message'), $_SERVER['REQUEST_URI']);
			}
		}
		return $show_message;
    }  

	static function controller() {
 		switch ($_REQUEST['action']) {
 		 case 'reset_pin' : self::reset_pin(); break;
 		 case 'change_pin': self::change_pin(); break;
 		}
		echo self::fetch_message(array('reset_pin','change_pin','save'));
		$plugin = WPWHOOSH_FRIENDLY_NAME;
?>
    <div id="poststuff" class="metabox-holder">
     	<h2>Your <?php echo $plugin; ?> PIN</h2>    
     	<p>Click on the <i>Help</i> tab on the top right of the page for more about security.</p>
        <div id="post-body">
            <div id="post-body-content">
			<?php do_meta_boxes(self::get_screen_id(), 'normal', null); ?>
 			</div>
        </div>
        <br class="clear"/>
    </div>
<?php
	}  

}
?>